#
# spec file for package sca-server-report
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sca_common sca
%define sca_config sca
%define libbase /usr/lib/%{sca_common}
%define sca_python %{libbase}/python

Name:           sca-server-report
Version:        1.6.4
Release:        1.1
Summary:        Supportconfig Analysis Server Report
License:        GPL-2.0-only
URL:            https://github.com/g23guy/sca-server-report
Group:          System/Monitoring
Source:         %{name}-%{version}.tar.gz
Requires:       python3-base
Requires:       sca-patterns-base >= 1.6.2
Requires:       sca-patterns-template-gen2
BuildArch:      noarch

%description
A tool that primarily analyzes the local server, but can analyze other
supportconfigs that have been copied to the server. It uses the
Supportconfig Analysis patterns to perform the analysis.

See %{_docdir}/sca-patterns-base/COPYING.GPLv2

%prep
%setup -q

%build
gzip -9f man/*5
gzip -9f man/*8

%install
pwd;ls -la
install -d %{buildroot}%{_sysconfdir}/%{sca_config}
install -d %{buildroot}%{_mandir}/man5
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{sca_python}
mkdir -p %{buildroot}%{_bindir}
install -m 755 bin/scatool %{buildroot}%{_bindir}
install -m 644 config/scatool.conf %{buildroot}%{_sysconfdir}/%{sca_config}
install -m 644 man/*.5.gz %{buildroot}%{_mandir}/man5
install -m 644 man/*.8.gz %{buildroot}%{_mandir}/man8

%files
%defattr(-,root,root)
%{_bindir}/scatool
%dir %{_sysconfdir}/%{sca_config}
%config %{_sysconfdir}/%{sca_config}/*
%doc %{_mandir}/man5/*
%doc %{_mandir}/man8/*

%changelog
* Fri May  9 2025 jason.record@suse.com
- Changes to version 1.6.4
  + Fixed all report type data (bsc#1242706)
  + Added -a/--all_reports option for all report types
  + Fixed re syntax error (bsc#1241308)
  + Fixed hardware tag for Power (bsc#1237320)
* Mon Oct  7 2024 jason.record@suse.com
- Fixed extract here for reports regression
* Fri Oct  4 2024 jason.record@suse.com
- Changes to version 1.6.3
  + Corrected error message for unreadable supportconfigs (bsc#1230857)
  + Valid product labels for SLE Micro (bsc#1230862)
  + Unknown supportconfig products produce valid error (bsc#1230880)
  + Doesn't hang on access issues for extraction (bsc#1230881)
  + Added -x, --extract_here options (bsc#1230882)
  + Made debug messages have consistent format (bsc#1231049)
  + Default report path uses given extract path (bsc#1231259)
  + Combined the file checking and reporting loops (bsc#1231286)
  + Only gets extract_here and report_output_path once (bsc#1231287)
* Mon Jan 29 2024 jason.record@suse.com
- Changes to version 1.6.2
  + Missing supportconfig key (bsc#1219252)
  + Includes SLE Micro (bsc#1219255)
  + SUMA detection (bsc#1219257)
* Tue Jan  9 2024 jason.record@suse.com
- Changes to version 1.6.1
  + Removed dev from version string in scatool
  + Removed todo lists from scatool
  + Ready for install (bsc#1218572)
* Wed Nov 29 2023 jason.record@suse.com
- Changes in version 1.6.0
  + Updates for ALP using new classes and modules (bsc#1217674)
* Mon Aug 21 2023 jason.record@suse.com
- Changes in version 1.5.2
  + Fixed scatool email failure with python3 (bsc#1192315)
  + Allow batch mode that does not have progress bar issue#13 (pr#14)
  + Added quiet and debug modes issue#11
* Mon Mar  7 2022 Jason Record <jason.record@suse.com>
- Changes to updated version 1.5.1
  + The legacy SuSE-release file works (bsc#1196730)
* Thu Nov  4 2021 Jason Record <jason.record@suse.com>
- Changes to updated version 1.5.0
  + Converted code base from python2 to python3 (bsc#119105, SLE-21579)
* Mon Oct  4 2021 Jason Record <jason.record@suse.com>
- Added python2 to requires (bsc#1191199)
* Tue May 25 2021 Jason Record <jason.record@suse.com>
- Fixed sca report header supportconfig file (bsc#1186442)
- Fixed report file output path (bsc#1180894)
- Removed preprocessor elements for OES Filr eDir (bsc#1186420)
* Thu May 20 2021 Jason Record <jason.record@suse.com>
- Changed absolute paths to relative ones (bsc#1186316)
* Thu Nov 12 2020 jason.record@suse.com
- Additional to version 1.0.1
  + Updated the man pages with -r
  + -k is retained for compatibility, but keeping the archive is default
  + Fixed service pack version when GA
  + Print actual hostname instead of localhost with -s
  + scatool trys to run README file (bsc#1178528)
* Fri Nov  6 2020 jason.record@suse.com
- Additions to version 1.0.1
  + Updated man pages for scatool(8) and scatool.conf(5)
  + Removed CONSOLE_MODE from scatool.conf
  + should support archive or server argument and not require -a (bsc#1178229)
  + scatool copies remote scc_* supportconfigs (bsc#1178151)
  + Exits gracefully when attempting to process damaged files (bsc#1178152)
  + scatool correctly cleans up and saves archives (bsc#1178094)
* Sat Oct 24 2020 jason.record@suse.com
- Additions to version 1.0.1
  + Arg with / treated as files, not remote servers (bsc#1178099)
  + Optimized tar ball extraction (bsc#1178093)
  + Added /etc/os-release support (bsc#1178092)
  + scatool correctly process -s for local server (bsc#1178088)
  + Fixed progress bar timing (bsc#1178086)
  + Fixed scatool fails with no module named readline (bsc#1177249)
  + If run against path '.' use cwd name (issue#1)
  + Added support for xz compression (bsc#1155181)
* Mon Jan 22 2018 jason.record@suse.com
- Fixed pattern runtime error divide by zero (bsc#1077110)
* Fri Jan  5 2018 jason.record@suse.com
- Added SLE15 detection (bsc#1073573)
* Tue Jan  2 2018 jason.record@suse.com
- Removed unnecessary %%clean from spec
* Mon Dec 18 2017 jason.record@suse.com
- Updated spec file with spec-cleaner suggestions
- Removed COPYING.GPLv2 and referenced sca-patterns-base
- Fixed new config file path
* Wed Apr 19 2017 jason.record@suse.com
- Updated scatool.py version
- Added a -p option to show the pattern summary (bsc#1035047)
- Updated scatool.8 man page with -p
* Fri Mar  4 2016 jrecord@suse.com
- Updated scatool.8 man page
- Added _report.html to SCA Report files (bsc#969672)
* Thu Mar  3 2016 jrecord@suse.com
- Clarified base element error message
* Wed Dec  9 2015 jrecord@suse.com
- Fixed index out of range error (bsc#958422)
- Added total available patterns
* Thu Jan 15 2015 jrecord@suse.com
- Added additional product header entries
* Fri Nov 14 2014 jrecord@suse.com
- Fixed scatool man page for email list
- Added SUMA pattern definition
* Wed Jun 11 2014 jrecord@suse.com
- Changed relative paths to full path
- Added email functionality in OPTION_EMAIL_LIST and -e (bnc#880815)
- Fixed invalid pattern source links (bnc#881187)
- Fixed the HAE preprocessor (bnc#881403)
* Wed May 28 2014 jrecord@suse.com
- Changed waiting prompt on remote connections
* Tue May 20 2014 jrecord@suse.com
- Cleaned up error message on failed supportconfig copy
- Adjusted supportconfig progress bar
* Sat May  3 2014 jrecord@suse.com
- Improved error handling
* Fri May  2 2014 jrecord@suse.com
- Added remote supportconfig progress bar
- Added -s supportconfig progress bar
- Fixed -c for console mode (bnc#876045)
- Fixed invalid supportconfig run date (bnc#876040)
* Mon Apr 21 2014 jrecord@suse.com
- Added summary to report footer
- Added severity section total in report
- Cell padding in header table
- Added severityTag to expandable report title
* Thu Apr 17 2014 jrecord@suse.com
- Fixed incomplete overall info strings (bnc#873989)
- Fixed invalid pattern info link (bnc#874022)
- Fixed arg with unknown option (bnc#874036)
- Added HTML report footer (bnc#874029)
- Change to lowercase pattern directories
- Fixed GroupWise preprocessor detection (bnc#873991)
* Tue Apr 15 2014 jrecord@suse.com
- Fixed location of extracting archive
- Updated email David Hamner (ke7oxh@gmail.com)
- Updated output strings for consistency
* Mon Apr 14 2014 jrecord@suse.com
- Fixed error processing
- Fixed remote server supportconfig filenames
- Added /etc/sca/scatool.conf
- Added scatool.conf(5)
* Sun Apr 13 2014 jrecord@suse.com
- Fixed treating relative path as remote connection (bnc#873075)
- Progress bar in normal mode
- Each pattern listed in verbose mode
- Uses standard SCA_LIBRARY_PATH
* Fri Apr 11 2014 jrecord@suse.com
- Fixed remote server failure processing (bnc#873289)
* Fri Apr 11 2014 jrecord@suse.com
- Output formatting updated
- Updated man page with correct startup options
- Fixed invalid IP addr handling (bnc#873181)
- Fixed errors on zero byte files (bnc#873076)
* Fri Apr 11 2014 jrecord@suse.com
- Fixed rpm file not found pything dump (bnc#872368)
- Fixed verbose display with -v
- Added Supportconfig Run Date to report header
- Fixed invalid html report file for directories
- Fixed archive file in report header
- Fixed static html title to include archive server name
- Report date matches SCA Appliance
- Fixed duplicate SLED in OES Distribution header
- Fixed command line option handling using getopt
- Separated -s from -a, -s is a local server analysis
- Added a title
* Thu Mar 27 2014 jrecord@suse.com
- Fixed bash library path so bash patterns execute
- Removed unused Samba filter
* Fri Mar 21 2014 jrecord@suse.com
- Clarified man page options
- Removed scatool.py hash pling
- Updated man page header
- Moved scatool.py to library
- Fixed FSF address in files
- Change to System/Monitoring spec Group
* Thu Feb 13 2014 jrecord@suse.com
- Fixed analyze() and runPats(extractedSupportconfig) error
* Tue Feb 11 2014 jrecord@suse.com
- Updated the man page
- Removed console as a default
* Fri Jan 31 2014 ke7oxh@gmail.com
- Added .changes
* Thu Jan 16 2014 jrecord@suse.com
- updated paths to match FHS change
* Fri Nov 15 2013 ke7oxh@gmail.com
- Fixed HTML ouput
- Analyze run from console will auto start w3m
* Fri Nov  8 2013 jrecord@suse.com
- initial package
